@@ -11,5 +11,7 @@ router.APIRootView = NetboxStorageRootView
 
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
+router.register("linuxvolume", DriveViewSet)
+router.register("windowsvolume", FilesystemViewSet)
 
 urlpatterns = router.urls
